# ancIBD
This Python software package screens ancient human DNA for long IBD blocks (Identity by Descent segments) shared between pairs of individuals.

Please find the official documentation and installation instructions at [the official ancIBD readthedocs page](https://ancibd.readthedocs.io/en/latest/Intro.html).